==> zio-aws-schemas_2.13-5.17.129.1-sources.jar: zio/aws/schemas/model/DescribeRegistryRequest.scala <==
package zio.aws.schemas.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.schemas.model.primitives.__string
import scala.jdk.CollectionConverters._
final case class DescribeRegistryRequest(registryName: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.schemas.model.DescribeRegistryRequest = {
    import DescribeRegistryRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.schemas.model.DescribeRegistryRequest
      .builder()
      .registryName(__string.unwrap(registryName): java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.schemas.model.DescribeRegistryRequest.ReadOnly =
    zio.aws.schemas.model.DescribeRegistryRequest.wrap(buildAwsValue())
}
object DescribeRegistryRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.schemas.model.DescribeRegistryRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.schemas.model.DescribeRegistryRequest =
      zio.aws.schemas.model.DescribeRegistryRequest(registryName)
    def registryName: __string
    def getRegistryName: ZIO[Any, Nothing, __string] = ZIO.succeed(registryName)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.schemas.model.DescribeRegistryRequest
  ) extends zio.aws.schemas.model.DescribeRegistryRequest.ReadOnly {
    override val registryName: __string =
      zio.aws.schemas.model.primitives.__string(impl.registryName())
  }
  def wrap(
      impl: software.amazon.awssdk.services.schemas.model.DescribeRegistryRequest
  ): zio.aws.schemas.model.DescribeRegistryRequest.ReadOnly = new Wrapper(impl)
}

==> zio-aws-schemas_2.13-6.20.58.1-sources.jar: zio/aws/schemas/model/DescribeRegistryRequest.scala <==
package zio.aws.schemas.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.schemas.model.primitives.__string
import scala.jdk.CollectionConverters._
final case class DescribeRegistryRequest(registryName: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.schemas.model.DescribeRegistryRequest = {
    import DescribeRegistryRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.schemas.model.DescribeRegistryRequest
      .builder()
      .registryName(registryName: java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.schemas.model.DescribeRegistryRequest.ReadOnly =
    zio.aws.schemas.model.DescribeRegistryRequest.wrap(buildAwsValue())
}
object DescribeRegistryRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.schemas.model.DescribeRegistryRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.schemas.model.DescribeRegistryRequest =
      zio.aws.schemas.model.DescribeRegistryRequest(registryName)
    def registryName: __string
    def getRegistryName: ZIO[Any, Nothing, __string] = ZIO.succeed(registryName)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.schemas.model.DescribeRegistryRequest
  ) extends zio.aws.schemas.model.DescribeRegistryRequest.ReadOnly {
    override val registryName: __string = impl.registryName(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.schemas.model.DescribeRegistryRequest
  ): zio.aws.schemas.model.DescribeRegistryRequest.ReadOnly = new Wrapper(impl)
}
